---
title: Home
description: OpenSymbiose
hide:
  - navigation
---
# OpenSymbiose: Open Source Biotechnology AI Agent
OpenSymbiose in an open-source biotechnology / biology research AI agent designed to support researcher.

Creator and Maintainer: [**Corentin Meyer**, PhD](https://cmeyer.fr/) - <contact@cmeyer.fr>

## Installation
From PyPi: `pip install opensymbiose`

## Usage
Placeholder
